@@ -311,28 +311,18 @@ class Analysis(object):
 	to two separate worksheets in the ".xlsx" workbook.
 	
 	:param wbname: ".xlsx" file on disk (i.g. "Barriers.xlsx")
-	:param barsheet: worksheet in ".xlsx" containing Barrier Design Table
 	:param sndsheet: "worksheet in ".xlsx" containing Sound Level Results
 	:param barriercost: cost of barrier design, as reported by TNM 2.5
 	"""
 
-	def __init__(self, wbname, barsheet, sndsheet, barcost=0):
+	def __init__(self, wbname, sndsheet, barcost=0):
 		self._wbname = wbname
-		self._barsheet = barsheet
 		self._sndsheet = sndsheet
-		if barsheet == sndsheet:
-			raise ValueError("Worksheets cannot be identical!")
-		self.barriercost = barcost
-		self._barrecs = self._wbhandler(barsheet)
+		self.barriercost = barcost		
 		self._sndrecs = self._wbhandler(sndsheet)
 		"""Receivers listed in the Sound Results worksheet"""
-		self.snd_rec_list = [
-                                  (i[0].value, i[2].value, i[8].value) 
-                                      for i in self._sndrecs
-                               ]
-		self.impacted_recs = [(i[0], i[1]) for i in self.recs_analysis 
-                                      if i[4] != " ----"
-                                ]
+		self.snd_rec_list = [(f"{i[0].value}".strip(), i[2].value, i[8].value.strip()) for i in self._sndrecs]
+		self.impacted_recs = [i for i in self.snd_rec_list if i[2] != "----"]
 		self.impact_num = sum([tup[1] for tup in self.impacted_recs])
 		self.du_analysis = sum([tup[1] for tup in self.recs_analysis])
 		self.benefitted =  [
@@ -360,15 +350,10 @@ class Analysis(object):
 		if not ws:
 			raise ValueError("Excel worksheet not found!" + 
                                        "Is it spelled correctly?")
-		if sht == self._barsheet:
-			lastrow = ws.max_row
-			#assumes copied from TNM bar sound results in cell A1
-			datarange = 'B18:L{}'.format(lastrow)
-		elif sht == self._sndsheet:
-			#omit last 8 rows in snd results
-			lastrow = ws.max_row - 8
-			datarange = 'B20:N{}'.format(lastrow)
-		reclist = list(ws.iter_rows(range_string=datarange))
+		# omit last 8 rows in snd results
+		lastrow = ws.max_row - 8
+		# limit to appropriate columns 
+		reclist = list(ws.iter_rows(min_col=2, max_col=14, min_row=20, max_row=lastrow))
 		return reclist
 	@property		
 	def recs_analysis(self):
@@ -376,21 +361,9 @@ class Analysis(object):
 		List receivers, DU, barrier reduction value, reduction goal, and
 		impact status in chosen barrier analysis
 		"""
-		barreclist = self._barrecs
 		sndreclist = self._sndrecs
-		r = []
-		for barrec in barreclist:
-			rec = barrec[0].value
-			barred = barrec[3].value
-			redgoal = barrec[4].value
-			for sndrec in sndreclist:
-				if rec == sndrec[0].value:
-					du = sndrec[2].value
-					impstat = sndrec[8].value
-					r.append((rec, du, barred, redgoal, impstat))
-				else:
-					pass
-		return sorted(r)
+		return [("1A", 1, 5.5, 8, " ----")]
+		# return (rec, du, barred, redgoal, impstat)
 	@property
 	def benefits(self):
 		"""
@@ -450,29 +423,7 @@ class Analysis(object):
 		    return 0
 		else:
 		    return self.barriercost / self.benefit_num
-	def report(self):
-		"""
-		Report of results. Useful for report writing or debugging.
-		"""
-		pass
-		# print("Receivers/receptors in barrier analysis: {} ({})".format(\
-        #                       len(self.recs_analysis), self.du_analysis))
-		# print "Impacts in barrier analysis: {} ({})".format(\
-        #                       len(self.impacted_recs), self.impact_num)
-		# print "Benefits in barrier analysis: {} ({})".format(\
-        #                       len(self.benefitted), self.benefit_num)
-		# print "Number of impacts receiving 5dBA reduction: {}".format(\
-        #                       self.ben_and_imp_num)
-		# print "Impacts (%) receiving 5dBA reduction: {}".format(\
-        #                       self.perc_imp_benefitted)
-		# print "Benefits receiving 8dBA reduction: {} ({})".format(\
-        #                       len(self.reas_red_recs), self.reas_red_num) 
-		# print "Benefits (%) receiving reasonable reduction: {}".format(\
-        #                       self.perc_ben_reasonable) 
-		# print "Barrier design is feasible: {}".format(\
-        #                       self.feasible)
-		# print "Barrier design is reasonable: {}".format(\
-        #                       self.reasonable)
+
 
 # class GAAnalysis(Analysis):
 #     def __init__(self, wbname, barsheet, sndsheet, barcost=0):
@@ -501,19 +452,363 @@ class Analysis(object):
 # 		else:
 # 			return False
 
+class LouisianaAnalysis(Analysis):
+
+	def barrier_segments(self):
+		"""Read "Barrier_Segments" worksheet and return raw list of rows
+
+		Raises:
+			ValueError: Workbook needs to contain a worksheet called "Barrier Segments"
+
+		Returns:
+			[type]: [description]
+		"""
+		wb = p.load_workbook(self._wbname)
+		ws = wb.get_sheet_by_name("Barrier_Segments")
+		if not ws:
+			raise ValueError("Excel worksheet not found!" + 
+                                       "Is it spelled correctly?")
+		lastrow = ws.max_row
+		# limit to appropriate columns 
+		barrierlist = list(ws.iter_rows(min_col=2, max_col=14, min_row=16, max_row=lastrow))
+		return barrierlist
+	
+	def _barrier_infos(self):
+		"""
+		For each barrier in "Barrier_Segments", compiles list of barrier dimensions per segment		
+		Returns:
+			list: [[{ barrier: [(hgt, length, sqft)] }]]
+		"""
+		barrier_list = []
+		barrier_info = {}
+		barrier_tag = ""
+		row_count = (len(self.barrier_segments()))
+		for idx, row in enumerate(self.barrier_segments()):
+			barrier_name = row[0].value
+			barrier_point = row[4].value
+			barrier_height = row[6].value
+			barrier_length = row[8].value
+			barrier_sq_footage = row[9].value			
+			if (barrier_name and barrier_point): # check for barrier name
+				barrier_tag = barrier_name.strip()
+				barrier_dimensions = (barrier_length, barrier_height, barrier_sq_footage)
+				barrier_info[barrier_name.strip()] = []			
+				barrier_info[barrier_name.strip()].append(barrier_dimensions)
+			elif barrier_point:
+				barrier_dimensions = (barrier_length, barrier_height, barrier_sq_footage)
+				if (idx == row_count - 1): # deal with last row					
+					barrier_info[barrier_tag].append(barrier_dimensions)
+					barrier_list.append(barrier_info)
+				else:
+					barrier_info[barrier_tag].append(barrier_dimensions)
+			elif not barrier_point:				
+				barrier_list.append(barrier_info)		
+				barrier_info = {}
+		return barrier_list
+
+	def _barrier_dimensions(self):
+		"""[summary]
+
+		Returns:
+			[dict]: [{ barrier: {hgt: sqfootage, hgt:sqfootage, ...} }]
+		"""
+		barrier_info = {}
+		for barrier in self._barrier_infos():
+			barrier_name = [k for k in barrier.keys()][0]
+			barrier_segment_info = {}
+			segment_descriptions_list = barrier.values()
+			for segment_descriptions in segment_descriptions_list:
+				unique_heights = set([i[1] for i in segment_descriptions if i[1]]) #exclude zero height segments
+				for height in unique_heights:
+					square_footage = sum([i[2] for i in segment_descriptions if i[1] == height])
+					barrier_segment_info[height] = square_footage
+			barrier_info[barrier_name] = barrier_segment_info
+		return barrier_info
+
+	def barrier_segment_summary(self, barriers):
+		"""Given list of barriers, filter barrier dimension dictionary
+
+		Args:
+			barriers ([type]): [description]
+
+		Returns:
+			[type]: [description]
+		"""
+		barrier_selection = {}
+		for barrier in barriers:
+			try:
+				barrier_selection[barrier] = self._barrier_dimensions()[barrier]
+			except KeyError:
+				pass
+		return barrier_selection
+
+	def total_square_footage(self, barriers):
+		"""Given a list of barriers or single barrier in this analysis, return the total square footage 
+
+		Args:
+			barriers (list, string): [description]
+
+		Returns:
+			[int]: [description]
+		"""
+		if type(barriers) == list:
+			total_square_footage = 0
+			for barrier in barriers:
+				barrier_dimensions = self._barrier_dimensions()[barrier]
+				total_square_footage += sum([sf for sf in barrier_dimensions.values()])
+		else:
+			barrier_dimensions = self._barrier_dimensions()[barriers]
+			total_square_footage = sum([sf for sf in barrier_dimensions.values()])
+		return total_square_footage
+
+	def total_length(self, barriers):
+		"""Given list of barriers, return total length
+
+		Args:
+			barriers ([type]): [description]
+
+		Returns:
+			[type]: [description]
+		"""
+		barrier_info = {}
+		total_length = 0
+		for barrier in self._barrier_infos():
+			barrier_name = [k for k in barrier.keys()][0]
+			if barrier_name in barriers:
+				segment_descriptions_list = list(barrier.values())
+				total_length += sum([i[0] for i in segment_descriptions_list[0]])
+		return total_length
+
+	def min_max_height(self, barriers):
+		"""Given a list of barriers, what is the min height
+
+		Args:
+			barriers ([type]): [description]
+
+		Returns:
+			[type]: [description]
+		"""
+		barrier_info = {}
+		all_heights = []
+		for barrier in self._barrier_infos():
+			barrier_name = [k for k in barrier.keys()][0]
+			if barrier_name in barriers:
+				segment_descriptions_list = list(barrier.values())				
+				barrier_heights = [i[1] for i in segment_descriptions_list[0] if i[1] !=0] # ignore zero height segments
+				all_heights += barrier_heights
+		return min(all_heights), max(all_heights)
+
+	@property
+	def feasible(self):
+		"""
+		Barrier design is feasible if 75% or more of impacted receivers
+		receive a 5dBA or more noise reduction
+		"""
+		perc_crit = self.impact_num * 0.75
+		if self.benefit_num >= perc_crit:
+			return True
+		else:
+			return False
+	@property
+	def reasonable(self):
+		"""
+		Barrier design is reasonable if 80% or more of benefitted receivers
+		receive a 8dBA or more noise reduction
+		"""
+		perc_crit = self.benefit_num * 0.80
+		if perc_crit == 0:
+			return False
+		elif self.reas_red_num >= perc_crit:
+			return True
+		else:
+			return False
+
+def cost_per_square_foot(hgt, total_sqft):
+	"""Given total square footage and barrier height, return cost per square foot
+		DOTD Cost Table 2016
+		This is ugly, but functional
+
+	Args:
+		total_sq_foot ([type]): [description]
+		height ([type]): [description]
+	"""	
+	if hgt <= 10:
+		if total_sqft <= 10000:
+			cost_per_square_foot = 27
+		elif 10001 <= total_sqft <= 15000:
+			cost_per_square_foot = 26
+		elif 15001 <= total_sqft <= 20000:
+			cost_per_square_foot = 24
+		elif 20001 <= total_sqft <= 25000:
+			cost_per_square_foot = 23
+		elif 25001 <= total_sqft <= 30000:
+			cost_per_square_foot = 22
+		elif 30001 <= total_sqft <= 35000:
+			cost_per_square_foot = 22
+		elif 35001 <= total_sqft <= 40000:
+			cost_per_square_foot = 21
+		elif 40001 <= total_sqft <= 45000:
+			cost_per_square_foot = 21
+		elif 45001 <= total_sqft <= 50000:
+			cost_per_square_foot = 20
+		elif 50001 <= total_sqft <= 55000:
+			cost_per_square_foot = 20
+		elif 55001 <= total_sqft <= 60000:
+			cost_per_square_foot = 20
+		elif 60001 <= total_sqft <= 65000:
+			cost_per_square_foot = 20
+		elif 65001 <= total_sqft <= 70000:
+			cost_per_square_foot = 19
+		elif 70001 <= total_sqft <= 75000:
+			cost_per_square_foot = 19
+		elif 75001 <= total_sqft <= 80000:
+			cost_per_square_foot = 19
+		elif total_sqft >= 80001:
+			cost_per_square_foot = 19																																														
+	elif 11 <= hgt <= 14:
+		if total_sqft <= 10000:
+			cost_per_square_foot = 43
+		elif 10001 <= total_sqft <= 15000:
+			cost_per_square_foot = 41
+		elif 15001 <= total_sqft <= 20000:
+			cost_per_square_foot = 39
+		elif 20001 <= total_sqft <= 25000:
+			cost_per_square_foot = 37
+		elif 25001 <= total_sqft <= 30000:
+			cost_per_square_foot = 36
+		elif 30001 <= total_sqft <= 35000:
+			cost_per_square_foot = 35
+		elif 35001 <= total_sqft <= 40000:
+			cost_per_square_foot = 34
+		elif 40001 <= total_sqft <= 45000:
+			cost_per_square_foot = 33
+		elif 45001 <= total_sqft <= 50000:
+			cost_per_square_foot = 33
+		elif 50001 <= total_sqft <= 55000:
+			cost_per_square_foot = 32
+		elif 55001 <= total_sqft <= 60000:
+			cost_per_square_foot = 32
+		elif 60001 <= total_sqft <= 65000:
+			cost_per_square_foot = 31
+		elif 65001 <= total_sqft <= 70000:
+			cost_per_square_foot = 31
+		elif 70001 <= total_sqft <= 75000:
+			cost_per_square_foot = 30
+		elif 75001 <= total_sqft <= 80000:
+			cost_per_square_foot = 30
+		elif total_sqft >= 80001:
+			cost_per_square_foot = 30
+	elif 15 <= hgt <= 19:
+		if total_sqft <= 10000:
+			cost_per_square_foot = 78
+		elif 10001 <= total_sqft <= 15000:
+			cost_per_square_foot = 76
+		elif 15001 <= total_sqft <= 20000:
+			cost_per_square_foot = 71
+		elif 20001 <= total_sqft <= 25000:
+			cost_per_square_foot = 68
+		elif 25001 <= total_sqft <= 30000:
+			cost_per_square_foot = 66
+		elif 30001 <= total_sqft <= 35000:
+			cost_per_square_foot = 64
+		elif 35001 <= total_sqft <= 40000:
+			cost_per_square_foot = 62
+		elif 40001 <= total_sqft <= 45000:
+			cost_per_square_foot = 61
+		elif 45001 <= total_sqft <= 50000:
+			cost_per_square_foot = 60
+		elif 50001 <= total_sqft <= 55000:
+			cost_per_square_foot = 59
+		elif 55001 <= total_sqft <= 60000:
+			cost_per_square_foot = 58
+		elif 60001 <= total_sqft <= 65000:
+			cost_per_square_foot = 57
+		elif 65001 <= total_sqft <= 70000:
+			cost_per_square_foot = 56
+		elif 70001 <= total_sqft <= 75000:
+			cost_per_square_foot = 56
+		elif 75001 <= total_sqft <= 80000:
+			cost_per_square_foot = 55
+		elif total_sqft >= 80001:
+			cost_per_square_foot = 55
+	elif 20 <= hgt <= 25:
+		if total_sqft <= 10000:
+			cost_per_square_foot = 151
+		elif 10001 <= total_sqft <= 15000:
+			cost_per_square_foot = 145
+		elif 15001 <= total_sqft <= 20000:
+			cost_per_square_foot = 136
+		elif 20001 <= total_sqft <= 25000:
+			cost_per_square_foot = 130
+		elif 25001 <= total_sqft <= 30000:
+			cost_per_square_foot = 126
+		elif 30001 <= total_sqft <= 35000:
+			cost_per_square_foot = 122
+		elif 35001 <= total_sqft <= 40000:
+			cost_per_square_foot = 119
+		elif 40001 <= total_sqft <= 45000:
+			cost_per_square_foot = 117
+		elif 45001 <= total_sqft <= 50000:
+			cost_per_square_foot = 115
+		elif 50001 <= total_sqft <= 55000:
+			cost_per_square_foot = 113
+		elif 55001 <= total_sqft <= 60000:
+			cost_per_square_foot = 111
+		elif 60001 <= total_sqft <= 65000:
+			cost_per_square_foot = 110
+		elif 65001 <= total_sqft <= 70000:
+			cost_per_square_foot = 108
+		elif 70001 <= total_sqft <= 75000:
+			cost_per_square_foot = 107
+		elif 75001 <= total_sqft <= 80000:
+			cost_per_square_foot = 106
+		elif total_sqft >= 80001:
+			cost_per_square_foot = 105
+	elif hgt >= 26:
+		if total_sqft <= 10000:
+			cost_per_square_foot = 229
+		elif 10001 <= total_sqft <= 15000:
+			cost_per_square_foot = 221
+		elif 15001 <= total_sqft <= 20000:
+			cost_per_square_foot = 208
+		elif 20001 <= total_sqft <= 25000:
+			cost_per_square_foot = 199
+		elif 25001 <= total_sqft <= 30000:
+			cost_per_square_foot = 192
+		elif 30001 <= total_sqft <= 35000:
+			cost_per_square_foot = 186
+		elif 35001 <= total_sqft <= 40000:
+			cost_per_square_foot = 182
+		elif 40001 <= total_sqft <= 45000:
+			cost_per_square_foot = 178
+		elif 45001 <= total_sqft <= 50000:
+			cost_per_square_foot = 175
+		elif 50001 <= total_sqft <= 55000:
+			cost_per_square_foot = 172
+		elif 55001 <= total_sqft <= 60000:
+			cost_per_square_foot = 169
+		elif 60001 <= total_sqft <= 65000:
+			cost_per_square_foot = 167
+		elif 65001 <= total_sqft <= 70000:
+			cost_per_square_foot = 165
+		elif 70001 <= total_sqft <= 75000:
+			cost_per_square_foot = 163
+		elif 75001 <= total_sqft <= 80000:
+			cost_per_square_foot = 161
+		elif total_sqft >= 80001:
+			cost_per_square_foot = 160
+	return cost_per_square_foot
+
+def barrier_cost(bar):
+	total_cost = 0
+	for hgt, total_sqft in bar.items():
+		total_cost += total_sqft * cost_per_square_foot(hgt, total_sqft)
+	return total_cost
+
+def barrier_summary(barrier_analysis, barriers):
+	"""Return length and total square foot of barrier or barrier system"""
+	return barrier_analysis.total_length(barriers), barrier_analysis.total_square_footage(barriers)
+
+
 if __name__ == '__main__':
-	os.chdir(os.path.dirname(__file__))
-	model_xlsx = '../files/tnm_model.xlsx'
-	build_model = Model(model_xlsx)
-	roadways = build_model.roadways	
-	# for roadway in roadways:
-	# 	print(roadway.traffic.auto.speed)
-	# 	print(roadway.traffic.medium.speed)
-	# 	print(roadway.traffic.heavy.speed)
-	# receivers = build_model.receivers	
-	# for receiver in receivers:
-	# 	print(receiver)
-	barriers = build_model.barriers
-	print(barriers)
-	for barrier in barriers:
-		print(barrier)
+	pass
